@@ -1,5 +1,5 @@
 name = "labelbox"
-__version__ = "3.11.0"
+__version__ = "3.13.0"
 
 from labelbox.schema.project import Project
 from labelbox.client import Client
@@ -13,7 +13,7 @@ from labelbox.schema.review import Review
 from labelbox.schema.user import User
 from labelbox.schema.organization import Organization
 from labelbox.schema.task import Task
-from labelbox.schema.labeling_frontend import LabelingFrontend
+from labelbox.schema.labeling_frontend import LabelingFrontend, LabelingFrontendOptions
 from labelbox.schema.asset_attachment import AssetAttachment
 from labelbox.schema.webhook import Webhook
 from labelbox.schema.ontology import Ontology, OntologyBuilder, Classification, Option, Tool, FeatureSchema
@@ -21,3 +21,5 @@ from labelbox.schema.role import Role, ProjectRole
 from labelbox.schema.invite import Invite, InviteLimit
 from labelbox.schema.data_row_metadata import DataRowMetadataOntology
 from labelbox.schema.model_run import ModelRun
+from labelbox.schema.benchmark import Benchmark
+from labelbox.schema.iam_integration import IAMIntegration
