@@ -1,3 +1,4 @@
+from labelbox.data.annotation_types.data.tiled_image import TiledImageData
 from labelbox.utils import camel_case
 from typing import List, Optional, Union
 
@@ -37,7 +38,9 @@ class LBV1LabelAnnotations(LBV1Classifications, LBV1Objects):
 class LBV1LabelAnnotationsVideo(LBV1LabelAnnotations):
     frame_number: int = Field(..., alias='frameNumber')
 
-    def to_common(self):
+    def to_common(
+        self
+    ) -> List[Union[VideoClassificationAnnotation, VideoObjectAnnotation]]:
         classifications = [
             VideoClassificationAnnotation(
                 value=classification.to_common(),
@@ -171,8 +174,9 @@ class LBV1Label(BaseModel):
                          external_id=label.data.external_id,
                          **label.extra)
 
-    def _data_row_to_common(self) -> Union[ImageData, TextData, VideoData]:
-        # Use data row information to construct the appropriate annotatin type
+    def _data_row_to_common(
+            self) -> Union[ImageData, TextData, VideoData, TiledImageData]:
+        # Use data row information to construct the appropriate annotation type
         data_row_info = {
             'url' if self._is_url() else 'text': self.row_data,
             'external_id': self.external_id,
@@ -215,20 +219,22 @@ class LBV1Label(BaseModel):
                     f"Can't infer data type from row data. row_data: {self.row_data[:200]}"
                 )
 
-    def _has_object_annotations(self):
+    def _has_object_annotations(self) -> bool:
         return len(self.label.objects) > 0
 
-    def _has_text_annotations(self):
+    def _has_text_annotations(self) -> bool:
         return len([
             annotation for annotation in self.label.objects
             if isinstance(annotation, LBV1TextEntity)
         ]) > 0
 
-    def _row_contains(self, substrs):
+    def _row_contains(self, substrs) -> bool:
         return any([substr in self.row_data for substr in substrs])
 
-    def _is_url(self):
-        return self.row_data.startswith(("http://", "https://"))
+    def _is_url(self) -> bool:
+        return self.row_data.startswith(
+            ("http://", "https://", "gs://",
+             "s3://")) or "tileLayerUrl" in self.row_data
 
     class Config:
         allow_population_by_field_name = True
